@@ -45,6 +45,7 @@ def create_parser():
     add_game_argument(decode)
     decode.add_argument("--format", help="Hint the format of the file. Defaults to extension.")
     decode.add_argument("--re-encode", help="Re-encode afterwards and compares to the original.", action="store_true")
+    decode.add_argument("--dump-to", help="Write to the given path a json encoded contents of the file", type=Path)
     decode.add_argument("input_path", type=Path, help="Path to the file")
 
     replace_pkg_file = subparser.add_parser("replace-in-pkg")
@@ -55,6 +56,7 @@ def create_parser():
     replace_pkg_file.add_argument("asset_path", type=Path, help="Path to the updated asset")
 
     find_pkg = subparser.add_parser("find-pkg-for")
+    add_game_argument(find_pkg)
     find_pkg.add_argument("--root", type=Path, required=True, help="Path to the PKG files")
     group = find_pkg.add_mutually_exclusive_group(required=True)
     group.add_argument("--asset-name", type=str, help="Asset name to find")
@@ -96,7 +98,11 @@ def do_decode(args):
 
     raw = input_path.read_bytes()
     decoded_resource = resource_class.parse(raw, target_game=game)
-    print(decoded_resource.raw)
+
+    if args.dump_to:
+        dump_to(args.dump_to, decoded_resource.raw)
+    else:
+        print(decoded_resource.raw)
 
     if re_encode:
         encoded = decoded_resource.build()
@@ -138,7 +144,7 @@ def find_pkg_for(args):
     asset_id: int = args.asset_id
     asset_name: str = args.asset_name
 
-    pkg_editor = FileTreeEditor(root)
+    pkg_editor = FileTreeEditor(root, args.game)
     if asset_id is not None:
         items = list(pkg_editor.find_pkgs(asset_id))
     else:
