@@ -10,6 +10,7 @@ from mercury_engine_data_structures.formats.bmsas import Bmsas
 from mercury_engine_data_structures.formats.bmscc import Bmscc
 from mercury_engine_data_structures.formats.bmscu import Bmscu
 from mercury_engine_data_structures.formats.bmsld import Bmsld
+from mercury_engine_data_structures.formats.bmsnav import Bmsnav
 from mercury_engine_data_structures.formats.bmslgroup import Bmslgroup
 from mercury_engine_data_structures.formats.bmslink import Bmslink
 from mercury_engine_data_structures.formats.bmssd import Bmssd
@@ -42,6 +43,7 @@ ALL_FORMATS = {
     "BMSCD": Bmscc,
     "BMSCU": Bmscu,
     "BMSLD": Bmsld,
+    "BMSNAV": Bmsnav,
     "BMSLGROUP": Bmslgroup,
     "BMSLINK": Bmslink,
     "BMTRE": Bmtre,
