@@ -4,7 +4,7 @@ from construct import Construct, Container
 from mercury_engine_data_structures.formats import BaseResource, standard_format
 from mercury_engine_data_structures.game_check import Game
 
-BRSA = standard_format.game_model('CSubAreaManager', 0x02010002)
+BRSA = standard_format.game_model('CSubAreaManager', 0x02010002).compile()
 
 
 class Brsa(BaseResource):
